@@ -2,7 +2,7 @@
 ##  Funcion de enlace: Combinacin de mtodos factoriales y de clasificacin no            ##
 ##  supervisada.                                                                           ##
 ##                                                                                         ##
-##                                                                                         ##
+##  Mayo 15 de 2011 inclusin de parmetro de pesos en funcin FactoClass (CEPT)           ##
 ##                                                                                         ##
 ## Elaborado por: Pedro Cesar del Campo Neira                                              ##
 ## Revisado y modificado por: Campo Elas Pardo  INGLS  Nov.30/07                         ##
@@ -27,20 +27,21 @@
 #############################################################################################
 
 
-FactoClass<-function( dfact, metodo, dfilu = NULL , nf = 2, nfcl = 10, k.clust = 3, 
+FactoClass<-function( dfact, metodo,dfilu = NULL , nf = 2, nfcl = 10, k.clust = 3, 
                       scanFC = TRUE , n.max = 5000 , n.clus = 1000 ,sign = 2.0,
-                      conso=TRUE , n.indi = 25 )
+                      conso=TRUE , n.indi = 25,row.w = rep(1, nrow(dfact)))
 {
 
   n <- dim(dfact)[1]
 
   n.act  <- deparse(substitute(dfact))  ### Tipo caracter nombre de dfact
   metodo <- deparse(substitute(metodo)) ### Tipo caracter nombre de la funcin
-
-  call1 <- call(metodo,df = as.name(n.act), nf = nf , scannf = scanFC) ### construccion del llamado 
-                                                                       ### funcin dudi
+ ### construccion del llamado funcin dudi modificada para pesos en acm y acp
+  if(metodo=="dudi.coa") call1 <- call(metodo,df = as.name(n.act), nf = nf , scannf = scanFC)
+     else call1 <- call(metodo,df = as.name(n.act), nf = nf , scannf = scanFC,row.w=row.w) 
+                                                                        
   par(las=1)                                                                      
-  DuDi1 <- eval(call1) # evaluacin del llamado funcin dudi
+  DuDi1 <- eval(call1) # evaluacin del llamado funcin dudi.*
   nf    <- DuDi1$nf
   cat("The number of retained axes for factorial analysis is ",nf,"\n\n") 
 
